@@ -9,11 +9,12 @@ https://github.com/figorr/solarmoonpy
 
 # solarmoonpy/__init__.py
 from .version import __version__
-from .moon import moon_phase, moon_rise_set, illuminated_percentage, moon_distance, moon_angular_diameter
+from .moon import moon_phase, moon_day, moon_rise_set, illuminated_percentage, moon_distance, moon_angular_diameter
 from .location import Location, LocationInfo
 
 __all__ = [
-    "moon_phase", 
+    "moon_phase",
+    "moon_day", 
     "moon_rise_set", 
     "illuminated_percentage", 
     "moon_distance", 
